@@ -40,7 +40,10 @@ def _get_message_size(size_base):
 _SMALL_MESSAGE_SIZE = _get_message_size(0.001)
 _MEDIUM_MESSAGE_SIZE = _get_message_size(0.01)
 _LARGE_MESSAGE_SIZE = _get_message_size(0.1)
-_REJECTABLE_MESSAGE_SIZE = _get_message_size(1.1)
+# rejectable message must be larger than [service]max_log_size
+# from monasca-log-api.conf
+_reject_size = CONF.monitoring.log_api_max_log_size/_ONE_MB + 0.1
+_REJECTABLE_MESSAGE_SIZE = _get_message_size(_reject_size)
 
 
 def generate_unique_message(message=None, size=50):
@@ -93,11 +96,13 @@ def _get_data(message):
 
 
 class BaseLogsTestCase(test.BaseTestCase):
-    """Base test case class for all Monitoring API tests."""
+    """Base test case class for all Logs tests."""
 
     @classmethod
     def skip_checks(cls):
         super(BaseLogsTestCase, cls).skip_checks()
+        if not CONF.service_available.logs:
+            raise cls.skipException("Monasca logs support is required")
 
     @classmethod
     def resource_setup(cls):
@@ -120,3 +125,13 @@ class BaseLogsTestCase(test.BaseTestCase):
                 method(resource_id)
             except exceptions.EndpointNotFound:
                 pass
+
+
+class BaseLogsSearchTestCase(BaseLogsTestCase):
+    """Base test case class for all LogsSearch tests."""
+    @classmethod
+    def skip_checks(cls):
+        super(BaseLogsSearchTestCase, cls).skip_checks()
+        # logs-search tests need both, 'logs' and 'logs-search'
+        if not CONF.service_available.logs_search:
+            raise cls.skipException("Monasca logs-search support is required")
